/*
** Modular Logfile Analyzer
** Copyright 2000 Jan Kneschke <jan@kneschke.de>
**
** Homepage: http://www.modlogan.org
**

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version, and provided that the above
    copyright and permission notice is included with all distributed
    copies of this or derived software.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA

**
** $Id: datatype.c,v 1.5 2004/08/27 18:32:54 ostborn Exp $
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <assert.h>

#include <zlib.h>

#include "config.h"
#include "mdatatypes.h"
#include "datatype.h"

/* begin of String */
extern size_t mem_mdata_type_count[M_DATA_TYPE_IPPLWATCH];

int mdata_String_to_xml(gzFile *fd, mdata *data) {
#define WR(x,f) \
	fprintf(fd, "<%s>%"#f"</%s>\n", #x, data->data.string.x, #x);

	/* WR(count, d); */
#undef WR
	return 0;
}

int mdata_String_free(mdata *data) {
	if (!data) return -1;
	if (data->type != M_DATA_TYPE_STRING) return -1;
	
	if (data->data.string.string) free(data->data.string.string);

	return 0;
}



int mdata_String_setdata(mdata *data, const char *str, const char *string) {
	assert(string);
	assert(str);
	
	data->key = str;
	assert(data->key);

	if (data->type == M_DATA_TYPE_UNSET)
		data->type		= M_DATA_TYPE_STRING;

	data->data.string.string	= strdup(string);
	mem_mdata_type_count[data->type]++;
	return 0;
}

int mdata_String_from_xml(mstate_stack *m, int tagtype, mdata *data, int type, const xmlChar *value, const xmlChar **attrs) {
	return 0;
}



int mdata_String_append(mdata *dst, mdata *src) {
	fprintf(stderr, "%s.%d: (string) abstract function 'append' !!\n", __FILE__, __LINE__);

	return 0;
}

mdata *mdata_String_init() {
	mdata *data = mdata_init();
	assert(data);

	data->key	= NULL;
	data->type		= M_DATA_TYPE_STRING;

#ifdef DEBUG_DATATYPES
	fprintf(stderr, "%s.%d: got %ld (%d)\n", __FILE__, __LINE__, data->id, data->type);
#endif
/* init specifics */

	data->data.string.string        = NULL;

	return data;
}

mdata *mdata_String_copy(mdata *src) {
	mdata *data = mdata_String_init();
	assert(data);

	fprintf(stderr, "%s.%d: (string) abstract function 'copy' !!\n", __FILE__, __LINE__);

/*
	mdata_String_setdata(data, src->key, src->data.string.count, src->data.string.grouped);
*/
	return data;
}

mdata *mdata_String_create(const char *str, const char *string) {
	mdata *data = mdata_String_init();
	assert(data);
	
	mdata_String_setdata(data, str, string);

	return data;
}

/* end of String */
